@@ -11,7 +11,7 @@
 ;; This requires linking with NEW_LIBS='linux.o -lm'.
 
 
-(lisp:in-package "LISP")
+(in-package "LISP")
 
 (eval-when (compile eval)
   ; A temporary package, case-insensitive, so that we don't need to prefix
@@ -2956,6 +2956,4 @@
 (lisp:in-package "LISP")
 
 (eval-when (compile eval)
-  (delete-package "LINUX-AUX")
-)
-
+  (lisp:delete-package "LINUX-AUX"))
